pub enum CtmNetworkShuntItemNumStepsUb {
Variant0(NonnegativeInteger),
Variant1(Vec<NonnegativeInteger>),
}Expand description
upper bound for number of energized steps of shunt section (lower bound is always 0)
JSON schema
{
"description": "upper bound for number of energized steps of shunt section (lower bound is always 0)",
"anyOf": [
{
"$ref": "#/$defs/nonnegative_integer"
},
{
"type": "array",
"items": {
"$ref": "#/$defs/nonnegative_integer"
}
}
]
}Variants
Variant0(NonnegativeInteger)
Variant1(Vec<NonnegativeInteger>)