CtmNetworkShuntItem

Struct CtmNetworkShuntItem 

pub struct CtmNetworkShuntItem {
    pub bs: CtmNetworkShuntItemBs,
    pub bus: Uid,
    pub ext: Option<Value>,
    pub gs: CtmNetworkShuntItemGs,
    pub name: Option<String>,
    pub nominal_mva: Option<PositiveNumber>,
    pub num_steps_ub: CtmNetworkShuntItemNumStepsUb,
    pub status: Status,
    pub uid: Uid,
}
structure to hold shunt data

JSON schema
{
 "description": "structure to hold shunt data",
 "type": "object",
 "required": [
   "bs",
   "bus",
   "gs",
   "num_steps_ub",
   "status",
   "uid"
 ],
 "properties": {
   "bs": {
     "description": "[MVAr or pu] reactive power demand at v_bus = 1.0 pu, per step of each shunt section",
     "anyOf": [
       {
         "type": "number"
       },
       {
         "type": "array",
         "items": {
           "type": "number"
         }
       }
     ]
   },
   "bus": {
     "description": "uid of bus to which shunt is connected to",
     "$ref": "#/$defs/uid"
   },
   "ext": {
     "description": "additional shunt parameters currently not supported by CTM"
   },
   "gs": {
     "description": "[MW or pu] active power demand at v_bus = 1.0 pu, per step of each shunt section",
     "anyOf": [
       {
         "$ref": "#/$defs/nonnegative_number"
       },
       {
         "type": "array",
         "items": {
           "$ref": "#/$defs/nonnegative_number"
         }
       }
     ]
   },
   "name": {
     "description": "shunt name",
     "type": "string"
   },
   "nominal_mva": {
     "description": "[MVA] nominal apparent power of shunt (nameplate capacity)",
     "$ref": "#/$defs/positive_number"
   },
   "num_steps_ub": {
     "description": "upper bound for number of energized steps of shunt section (lower bound is always 0)",
     "anyOf": [
       {
         "$ref": "#/$defs/nonnegative_integer"
       },
       {
         "type": "array",
         "items": {
           "$ref": "#/$defs/nonnegative_integer"
         }
       }
     ]
   },
   "status": {
     "$ref": "#/$defs/status"
   },
   "uid": {
     "$ref": "#/$defs/uid"
   }
 }
}

Fields

bs: CtmNetworkShuntItemBs

[MVAr or pu] reactive power demand at v_bus = 1.0 pu, per step of each shunt section

bus: Uid

uid of bus to which shunt is connected to

ext: Option<Value>

additional shunt parameters currently not supported by CTM

gs: CtmNetworkShuntItemGs

[MW or pu] active power demand at v_bus = 1.0 pu, per step of each shunt section

name: Option<String>

shunt name

nominal_mva: Option<PositiveNumber>

[MVA] nominal apparent power of shunt (nameplate capacity)

num_steps_ub: CtmNetworkShuntItemNumStepsUb

upper bound for number of energized steps of shunt section (lower bound is always 0)

status: Statusuid: Uid

Implementations