pub struct CtmTemporalBoundary {
pub bus: Vec<CtmTemporalBoundaryBusItem>,
pub gen: Vec<CtmTemporalBoundaryGenItem>,
pub global_params: CtmTemporalBoundaryGlobalParams,
pub hvdc_p2p: Vec<CtmTemporalBoundaryHvdcP2pItem>,
pub shunt: Vec<CtmTemporalBoundaryShuntItem>,
pub storage: Vec<CtmTemporalBoundaryStorageItem>,
pub switch: Vec<CtmTemporalBoundarySwitchItem>,
pub transformer: Vec<CtmTemporalBoundaryTransformerItem>,
}Expand description
structure to hold data on initial conditions of power system (state prior to start of time series data)
JSON schema
{
"description": "structure to hold data on initial conditions of power system (state prior to start of time series data)",
"type": "object",
"required": [
"global_params"
],
"properties": {
"bus": {
"type": "array",
"items": {
"description": "structure to hold initial state of bus variables",
"type": "object",
"required": [
"uid",
"va"
],
"properties": {
"ext": {
"description": "additional bus initial condition parameters currently not supported by CTM"
},
"uid": {
"description": "uid of bus this record refers to",
"$ref": "#/$defs/uid"
},
"va": {
"description": "[deg] initial voltage angle",
"type": "number"
},
"vm": {
"description": "[kV or pu] initial voltage magnitude",
"$ref": "#/$defs/positive_number"
}
}
}
},
"gen": {
"type": "array",
"items": {
"description": "structure to hold initial state of generator variables",
"type": "object",
"required": [
"pg",
"uid"
],
"properties": {
"down_time": {
"description": "[h] if in service, zero, else time the unit has been out of service",
"$ref": "#/$defs/nonnegative_number"
},
"ext": {
"description": "additional generator initial condition parameters currently not supported by CTM"
},
"in_service_time": {
"description": "[h] if in service, time the unit has been in service, zero otherwise",
"$ref": "#/$defs/nonnegative_number"
},
"pg": {
"description": "[MW or pu] initial active power injection",
"type": "number"
},
"qg": {
"description": "[MW or pu] initial reactive power injection",
"type": "number"
},
"uid": {
"description": "uid of generator this record refers to",
"$ref": "#/$defs/uid"
}
}
}
},
"global_params": {
"description": "structure to hold global parameters of temporal boundary",
"type": "object",
"required": [
"time_elapsed"
],
"properties": {
"time_elapsed": {
"description": "[seconds] time elapsed since temporal_boundary conditions where present in the system",
"$ref": "#/$defs/nonnegative_number"
}
}
},
"hvdc_p2p": {
"type": "array",
"items": {
"description": "structure to hold initial state of hvdc point-to-point line variables",
"type": "object",
"required": [
"pdc_fr",
"pdc_to",
"uid"
],
"properties": {
"ext": {
"description": "additional hvdc point-to-point line initial condition parameters currently not supported by CTM"
},
"pdc_fr": {
"description": "[MW or pu] initial active power entering hvdc line at from bus",
"type": "number"
},
"pdc_to": {
"description": "[MW or pu] initial active power entering hvdc line at to bus",
"type": "number"
},
"qdc_fr": {
"description": "[MVAr or pu] initial reactive power entering hvdc line at from bus",
"type": "number"
},
"qdc_to": {
"description": "[MVAr or pu] initial reactive power entering hvdc line at to bus",
"type": "number"
},
"uid": {
"description": "uid of hvdc point-to-point this record refers to",
"$ref": "#/$defs/uid"
},
"vm_dc_fr": {
"description": "[kV or pu] initial dc side voltage at from converter",
"$ref": "#/$defs/positive_number"
},
"vm_dc_to": {
"description": "[kV or pu] initial dc side voltage at to converter",
"$ref": "#/$defs/positive_number"
}
}
}
},
"shunt": {
"type": "array",
"items": {
"description": "structure to hold initial state of shunt variables",
"type": "object",
"required": [
"num_steps",
"uid"
],
"properties": {
"ext": {
"description": "additional shunt initial condition parameters currently not supported by CTM"
},
"num_steps": {
"description": "[-] number of initial energized steps per section",
"anyOf": [
{
"$ref": "#/$defs/nonnegative_integer"
},
{
"type": "array",
"items": {
"$ref": "#/$defs/nonnegative_integer"
}
}
]
},
"uid": {
"description": "uid of shunt this record refers to",
"$ref": "#/$defs/uid"
}
}
}
},
"storage": {
"type": "array",
"items": {
"description": "structure to hold initial state of storage variables",
"type": "object",
"required": [
"energy",
"uid"
],
"properties": {
"energy": {
"description": "[MWh or pu*h] initial state of charge",
"$ref": "#/$defs/nonnegative_number"
},
"ext": {
"description": "additional storage initial condition parameters currently not supported by CTM"
},
"ps": {
"description": "[MW or pu] initial active power injection",
"type": "number"
},
"qs": {
"description": "[MW or pu] initial reactive power injection",
"type": "number"
},
"uid": {
"description": "uid of storage this record refers to",
"$ref": "#/$defs/uid"
}
}
}
},
"switch": {
"type": "array",
"items": {
"description": "structure to hold initial state of switch variables",
"type": "object",
"required": [
"state",
"uid"
],
"properties": {
"ext": {
"description": "additional switch initial condition parameters currently not supported by CTM"
},
"state": {
"description": "[-] binary indicator of switch initial status; 0 => open, 1 => closed",
"$ref": "#/$defs/binary"
},
"uid": {
"description": "uid of switch this record refers to",
"$ref": "#/$defs/uid"
}
}
}
},
"transformer": {
"type": "array",
"items": {
"description": "structure to hold initial state of transformer variables",
"type": "object",
"required": [
"ta",
"tm",
"uid"
],
"properties": {
"ext": {
"description": "additional transformer initial condition parameters currently not supported by CTM"
},
"ta": {
"description": "[deg] initial angle phase shift",
"type": "number"
},
"tm": {
"description": "[-] initial tap ratio",
"$ref": "#/$defs/positive_number"
},
"uid": {
"$ref": "#/$defs/uid"
}
}
}
}
}
}Fields
bus: Vec<CtmTemporalBoundaryBusItem>gen: Vec<CtmTemporalBoundaryGenItem>global_params: CtmTemporalBoundaryGlobalParamshvdc_p2p: Vec<CtmTemporalBoundaryHvdcP2pItem>shunt: Vec<CtmTemporalBoundaryShuntItem>storage: Vec<CtmTemporalBoundaryStorageItem>switch: Vec<CtmTemporalBoundarySwitchItem>transformer: Vec<CtmTemporalBoundaryTransformerItem>Implementations
Sourceimpl CtmTemporalBoundary
impl CtmTemporalBoundary
pub fn builder() -> CtmTemporalBoundary